@@ -20,7 +20,7 @@
 
 import pandas as _pd
 import numpy as _np
-from math import ceil as _ceil
+from math import ceil as _ceil, sqrt as _sqrt
 from scipy.stats import (
     norm as _norm, linregress as _linregress
 )
@@ -246,6 +246,26 @@ def sortino(returns, rf=0, periods=252, annualize=True):
     return res
 
 
+def adjusted_sortino(returns, rf=0, periods=252, annualize=True):
+    """
+    Jack Schwager's version of the Sortino ratio allows for
+    direct comparisons to the Sharpe. See here for more info:
+    https://archive.is/wip/2rwFW
+    """
+    data = sortino(returns, rf=0, periods=252, annualize=True)
+    return data / _sqrt(2)
+
+
+def gain_to_pain_ratio(returns, rf=0, resolution="D"):
+    """
+    Jack Schwager's GPR. See here for more info:
+    https://archive.is/wip/2rwFW
+    """
+    returns = _utils._prepare_returns(returns, rf).resample(resolution).sum()
+    downside = abs(returns[returns < 0].sum())
+    return returns.sum() / downside
+
+
 def cagr(returns, rf=0., compounded=True):
     """
     calculates the communicative annualized growth return
@@ -427,11 +447,6 @@ def profit_factor(returns):
     return abs(returns[returns >= 0].sum() / returns[returns < 0].sum())
 
 
-def gain_to_pain_ratio(returns):
-    """ shorthand for profit_factor() """
-    return profit_factor(returns)
-
-
 def cpc_index(returns):
     """
     measures the cpc ratio
